/****************************************************************************
** Meta object code from reading C++ file 'kplotwidget.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../kplotting-5.116.0/src/kplotwidget.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kplotwidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KPlotWidget_t {
    QByteArrayData data[14];
    char stringdata0[163];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KPlotWidget_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KPlotWidget_t qt_meta_stringdata_KPlotWidget = {
    {
QT_MOC_LITERAL(0, 0, 11), // "KPlotWidget"
QT_MOC_LITERAL(1, 12, 11), // "setShowGrid"
QT_MOC_LITERAL(2, 24, 0), // ""
QT_MOC_LITERAL(3, 25, 4), // "show"
QT_MOC_LITERAL(4, 30, 21), // "setObjectToolTipShown"
QT_MOC_LITERAL(5, 52, 11), // "leftPadding"
QT_MOC_LITERAL(6, 64, 12), // "rightPadding"
QT_MOC_LITERAL(7, 77, 10), // "topPadding"
QT_MOC_LITERAL(8, 88, 13), // "bottomPadding"
QT_MOC_LITERAL(9, 102, 15), // "backgroundColor"
QT_MOC_LITERAL(10, 118, 15), // "foregroundColor"
QT_MOC_LITERAL(11, 134, 9), // "gridColor"
QT_MOC_LITERAL(12, 144, 4), // "grid"
QT_MOC_LITERAL(13, 149, 13) // "objectToolTip"

    },
    "KPlotWidget\0setShowGrid\0\0show\0"
    "setObjectToolTipShown\0leftPadding\0"
    "rightPadding\0topPadding\0bottomPadding\0"
    "backgroundColor\0foregroundColor\0"
    "gridColor\0grid\0objectToolTip"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KPlotWidget[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       2,   14, // methods
       9,   30, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   24,    2, 0x0a /* Public */,
       4,    1,   27,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void, QMetaType::Bool,    3,

 // properties: name, type, flags
       5, QMetaType::Int, 0x00095001,
       6, QMetaType::Int, 0x00095001,
       7, QMetaType::Int, 0x00095001,
       8, QMetaType::Int, 0x00095001,
       9, QMetaType::QColor, 0x00095103,
      10, QMetaType::QColor, 0x00095103,
      11, QMetaType::QColor, 0x00095103,
      12, QMetaType::Bool, 0x00095003,
      13, QMetaType::Bool, 0x00095003,

       0        // eod
};

void KPlotWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<KPlotWidget *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->setShowGrid((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 1: _t->setObjectToolTipShown((*reinterpret_cast< bool(*)>(_a[1]))); break;
        default: ;
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<KPlotWidget *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< int*>(_v) = _t->leftPadding(); break;
        case 1: *reinterpret_cast< int*>(_v) = _t->rightPadding(); break;
        case 2: *reinterpret_cast< int*>(_v) = _t->topPadding(); break;
        case 3: *reinterpret_cast< int*>(_v) = _t->bottomPadding(); break;
        case 4: *reinterpret_cast< QColor*>(_v) = _t->backgroundColor(); break;
        case 5: *reinterpret_cast< QColor*>(_v) = _t->foregroundColor(); break;
        case 6: *reinterpret_cast< QColor*>(_v) = _t->gridColor(); break;
        case 7: *reinterpret_cast< bool*>(_v) = _t->isGridShown(); break;
        case 8: *reinterpret_cast< bool*>(_v) = _t->isObjectToolTipShown(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<KPlotWidget *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 4: _t->setBackgroundColor(*reinterpret_cast< QColor*>(_v)); break;
        case 5: _t->setForegroundColor(*reinterpret_cast< QColor*>(_v)); break;
        case 6: _t->setGridColor(*reinterpret_cast< QColor*>(_v)); break;
        case 7: _t->setShowGrid(*reinterpret_cast< bool*>(_v)); break;
        case 8: _t->setObjectToolTipShown(*reinterpret_cast< bool*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject KPlotWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<QFrame::staticMetaObject>(),
    qt_meta_stringdata_KPlotWidget.data,
    qt_meta_data_KPlotWidget,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *KPlotWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KPlotWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KPlotWidget.stringdata0))
        return static_cast<void*>(this);
    return QFrame::qt_metacast(_clname);
}

int KPlotWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QFrame::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 2;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 9;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 9;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 9;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 9;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 9;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
